@@ -93,7 +93,7 @@ def root():
 
 
 @lru_cache
-def load_user(username: str) -> Optional[dict]:
+def load_user(username: str, _cache=None) -> Optional[dict]:
     global db_path
     with FADatabase(db_path) as db:
         return db.users[username]
@@ -111,10 +111,10 @@ def load_user_stats(username: str, _cache=None) -> Dict[str, int]:
             {"replace(lower(author), '_', '')": username, "folder": "scraps"}, ["count(ID)"]
         ).fetchone()[0]
         stats["favorites"] = db.submissions.select(
-            {"favorite": f"%{username}%"}, ["count(ID)"], like=True
+            {"favorite": f"%|{username}|%"}, ["count(ID)"], like=True
         ).fetchone()[0]
         stats["mentions"] = db.submissions.select(
-            {"mentions": f"%{username}%"}, ["count(ID)"], like=True
+            {"mentions": f"%|{username}|%"}, ["count(ID)"], like=True
         ).fetchone()[0]
         stats["journals"] = db.journals.select(
             {"replace(lower(author), '_', '')": username}, ["count(ID)"]
@@ -186,6 +186,7 @@ def search_table(table: str, sort: str, order: str, params_serialised: str = "{}
 
         if "sql" in params:
             query: str = " or ".join(map(lambda q: f"({q})", params["sql"]))
+            query = re_sub(r"any(?= (!?=|(not )?(like|glob)|[<>]=?))", f"({'||'.join(cols_table)})", query)
             return (
                 list(db_table.cursor_to_dict(
                     db_table.select_sql(query, columns=cols_results, order=[f"{sort} {order}"]),
@@ -234,14 +235,14 @@ def user(username: str):
     if username != (username_clean := clean_username(username)):
         return redirect(f"/user/{username_clean}")
 
-    user_entry: Optional[dict] = load_user(username)
+    user_entry: Optional[dict] = load_user(username, _cache=m_time(db_path))
     user_stats: Dict[str, int] = load_user_stats(username, _cache=m_time(db_path))
 
     return render_template(
         "user.html",
         title=f"{app.name} · {username}",
         user=username,
-        folders=list(filter(bool, user_entry["FOLDERS"].split(","))) if user_entry else [],
+        folders=user_entry["FOLDERS"] if user_entry else [],
         gallery_length=user_stats["gallery"],
         scraps_length=user_stats["scraps"],
         favorites_length=user_stats["favorites"],
@@ -301,7 +302,7 @@ def search_user_favorites(username: str):
     return redirect(url_for(
         "search", table="submissions", **{
             **{k: request.args.getlist(k) for k in request.args},
-            "favorite": f"%{username}%"}))
+            "favorite": f"%|{username}|%"}))
 
 
 @app.route("/mentions/<username>")
@@ -310,7 +311,7 @@ def search_user_mentions(username: str):
     return redirect(url_for(
         "search", table="submissions", **{
             **{k: request.args.getlist(k) for k in request.args},
-            "mentions": f"%{username}%"}))
+            "mentions": f"%|{username}|%"}))
 
 
 @app.route("/search/<string:table>/")
@@ -464,6 +465,13 @@ def submission_thumbnail(id_: int, x: int = 150, y: int = None, filename: str =
 
     if sub_ext is None:
         return abort(404)
+    elif isfile(path := join(sub_dir, f"thumbnail.jpg")):
+        f_obj: BytesIO = BytesIO()
+        with Image.open(path) as img:
+            img.thumbnail((x, y)) if img.width > x or img.height > y else None
+            img.save(f_obj, "jpeg")
+        f_obj.seek(0)
+        return send_file(f_obj, attachment_filename=filename, mimetype="image/jpeg")
     elif sub_ext.lower() not in ("jpg", "jpeg", "png", "gif"):
         return abort(404)
     elif isfile(path := join(sub_dir, f"submission.{sub_ext}")):
